function launchSystemC_MQ(demoName, coreBehavior, varargin)
% launchSystemC_MQ : start SystemC simulation for given demo and core behavior.
%
% launchSystemC_MQ(demoName, coreBehavior)
%
% demoName     : one of {'pv2pv','pv2tlmch','pv2bfm','tb2xbar'}
% coreBehavior : one of {'simple_ram','sl_streaming_alg','sl_buffered_alg','ml_streaming_alg','ml_buffered_alg','sl_tb','ml_tb'}

%   Copyright 2008-2009 The MathWorks, Inc.

    if (nargin == 2)
        scdm = eslmqdemopkg.SystemCDemoManagerMQ(demoName,coreBehavior);
    elseif (nargin >= 3)
        scdm = eslmqdemopkg.SystemCDemoManagerMQ(demoName,coreBehavior, varargin{:});
    end
    scdm.initialize();
    scdm.createDemoPackage();
    scdm.compileSystemC();
    scdm.runSystemC();
end
